@@ -1,4 +1,4 @@
 unit module OuterModule;
-use v6;
+use v6.c;
 
 use InnerModule :ALL :EXPORT;
