@@ -1,4 +1,4 @@
+use v6.c;
 class LoadFromInsideAClass {
-    use lib 't/spec/packages';
     use Foo;
 }
