@@ -1,4 +1,4 @@
-use v6;
+use v6.c;
 
 # "module Foo; ..." is equivalent to "module Foo {...}", so it returns the Foo
 # module object, see thread "What do use and require evaluate to?" on p6l
